@@ -1,15 +1,22 @@
 from djangoldp.filters import LocalObjectFilterBackend
 from djangoldp.views import LDPViewSet
 from djangoldp.models import Model
+from django.http import Http404
 
 
 class CircleMembersViewset(LDPViewSet):
 
+    def get_parent(self):
+        raise NotImplementedError("get_parent not implemented in CircleMembersViewset")
+
     def is_safe_create(self, user, validated_data, *args, **kwargs):
         from djangoldp_circle.models import Circle, CircleMember
 
         try:
-            circle = Circle.objects.get(urlid=validated_data['circle']['urlid'])
+            if 'circle' in validated_data.keys():
+                circle = Circle.objects.get(urlid=validated_data['circle']['urlid'])
+            else:
+                circle = self.get_parent()
 
             # public circles any user can add
             if circle.status == 'Public':
@@ -20,6 +27,8 @@ class CircleMembersViewset(LDPViewSet):
                 return True
         except Circle.DoesNotExist:
             return True
+        except (KeyError, AttributeError):
+            raise Http404('circle not specified with urlid')
 
         return False
 
